SystemOrganization addCategory: #ScriptLoader12!

Object subclass: #ConfigurationOfPharoCore
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ScriptLoader12'!

!ConfigurationOfPharoCore classSide methodsFor: 'private' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfPharoCore classSide methodsFor: 'private' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfPharoCore classSide methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPharoCore classSide methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfPharoCore classSide methodsFor: 'loading' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfPharoCore classSide methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfPharoCore classSide methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
project

	^self new project! !

!ConfigurationOfPharoCore classSide methodsFor: 'unloading Metacello' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfPharoCore methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 4/4/2010 12:54'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

Object subclass: #ScriptLoader
	instanceVariableNames: 'repository inboxRepository repository39 repositorySqueakTrunk repository310 repositoryTaskForces repositoryMC repositoryTreated'
	classVariableNames: 'CheckImageInSyncWithUpdate CurrentMajorVersionNumber CurrentScriptVersionNumber CurrentUpdateVersionNumber CurrentlyIntegratingChanges LogStream PackagesBeforeLastLoad Repository'
	poolDictionaries: ''
	category: 'ScriptLoader12'!

!ScriptLoader commentStamp: 'StephaneDucasse 5/26/2010 20:49' prior: 0!
Pharo Process Description


---
Here is the pharo process.

General points
-----------------------
An enhancement
	- should be added to the bug tracker
	- announced to the mailing-list
	- asked for feedback 
	- results should be added to the BT entry

Fixed tag means ready for integration
Closed tag means integrated

A bug detected
	- discuss via the mailing-list
	- should be added to the bug tracker
	- fix are considered as enh (see point above)

When a fix is fixed it should be either post as cs to the BT entry or in the PharoInbox
as a Slice (a slice is an emtpy package that has as requirement other package composing the fix).

We have three projects:
	Pharo
	PharoInbox
	PharoTreatedInbox

A fix goes either from inbox to treatedInbox or to Pharo.
If a fix does not work it is moved to the TreatedInbox.
If a fix works it is integrated as follow - it will be moved from the Inbox to the TreatedInbox
and integrated and published in the Pharo project

To help browsing multiple repositories:

ScriptLoader new addExtraRepositories


+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Now the integration works in 4 main steps which can be steered by the following expression
ScriptLoader releaseMenu
or via the menu that can be shown/hidden using 
	ScriptLoader showIntegrationMenu
	ScriptLoader hideIntegrationMenu


1.) Start up a recent and clean image
	ScriptLoader new prepareNewUpdate
	
	This step will 
		- load the latest updates
		- load the latest ScriptLoader package from the Pharo repository.
		Indeed when we work on improving the ScriptLoader it may not be published in the update stream. 
		New versions can be available on the server but not part of the latest updates.
		Therefore the process always loads the latest version of scriptloader from the pharo repository.
		This point is important because when an integration failed, you have to check and optionally 
		remove the scriptloader package from the pharo repository.
		
		- check that the update.list (which contains the cs to load the packages) is in sync
		with the image current version. You have to download the latest version using a script like this one.
		Pay attention to update it so that it reflects the right version (ie 1.0, 1.1, 1.2...)
		     scp -p LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/updates.list .
		- snapshot the package version to detect dirty or changed but non dirty packages.

2.) Apply changes

	ScriptLoader new doneApplyingChanges
	
	This step will 
		- create an update method with can trigger the load of the packages and some pre/post actions
		- create a script method with describes all the package versions and it used by the update methods
		- save all the packages that are different (except some filtered packages)	
		into a local folder named package-to-be-tested.
		ScriptLoader, SLICE*.... and a couple of other packages are not considered to be included in the script method
			(check method packagesNotToSavePatternNames)
		

3.) Verify changes
	==> in a ***new*** image (in the current folder) execute:
	ScriptLoader new verifyNewUpdate

	This step will 
		- load in any order (so may break) the package previously saved
		in the packages to be tested.
		- this step is important because you may get simple changes with unexpected side effects and that 
		may break the load.
		

4.) If there are problems go to 2.) to fix them, else:
	ScriptLoader new publishChanges

	This step will
		- generate a new cs file whose purpose is to load the given version of the scriptloader and trigger the 
		correct update method.
		- add the name of the cs file to the end of the updates.list file local to the disc
		- copy all the package from the local directory to the Pharo
		
	After the updates.list and the cs file should be manually uploaded to the ftp (see below) 
	   scp "$1" LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/
	

5) in case of problems.
Think that if you pass the step 4 you may have a scriptLoader version that got published and that is reloaded 
during the first step.



CurrentMajorVersionNumber should contains a string '1.0', '1.1'....
This string will determine on which folder on the server the updates.list should be loaded.
	i.e., updates/pharo1.0, updates/pharo1.1 ....

--- Not to forget ---
To change the release stream
add a new method for each releaseStream
	ScriptLoader toPharoOne
	ScriptLoader toPharoOneDotOne
!

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate

	^ CheckImageInSyncWithUpdate ifNil: [CheckImageInSyncWithUpdate := true]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate: aBoolean

	CheckImageInSyncWithUpdate := aBoolean! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:15'!
currentMajorVersionNumber

	^ CurrentMajorVersionNumber ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:12'!
currentMajorVersionNumber: aNumber

	CurrentMajorVersionNumber := aNumber! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:06'!
currentlyIntegratingChanges

	CurrentlyIntegratingChanges isNil ifTrue: [self hideIntegrationMenu].
	^ CurrentlyIntegratingChanges! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:32'!
defaultMCWaitingFolder
	"self defaultMCWaitingFolder" 
	
	^ MCDirectoryRepository new directory: self waitingCacheFolder! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			(self new)
				installGofer;
				gofer ]! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
hideIntegrationMenu

	CurrentlyIntegratingChanges := false.! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'StephaneDucasse 5/14/2010 22:21'!
initialize

	CurrentMajorVersionNumber :=  1.1! !

!ScriptLoader class methodsFor: 'private' stamp: 'al 11/1/2008 20:03'!
loadLatestPackage: aString from: aPath
	| repository |
	
	repository := MCHttpRepository
		location: aPath
		user:  ''
		password: ''.
	self loadLatestPackage: aString fromRepository: repository! !

!ScriptLoader class methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
loadLatestPackage: aString fromRepository: aRepository
	| versionsBlock versions tries |
	
	versionsBlock := [ (aRepository allVersionNames select: [ :each |
		each beginsWith: aString ])
		asSortedCollection: [ :a :b |
			(a copyAfterLast: $.) asNumber <= (b copyAfterLast: $.) asNumber]].
	versions := versionsBlock value.
	tries := 0.
	[ versions isEmpty and: [ tries < 3 ] ] whileTrue: [
		versions := versionsBlock value.
		tries := tries + 1 ].
	versions isEmpty ifTrue: [ self error: 'problems when accessing squeaksource' ].
	
	aRepository versionReaderForFileNamed: (versions last , '.mcz') do: [:reader | | version |
		version := reader version.
		version load.
		version workingCopy repositoryGroup addRepository: aRepository]! !

!ScriptLoader class methodsFor: 'private' stamp: 'AlexandreBergel 10/23/2008 15:31'!
loadLatestPackage: aString fromSqueaksource: aDirectoryName
	" self loadLatestPackage: 'ScriptLoader' fromSqueaksource: 'Pharo' "

	self loadLatestPackage: aString from: 'http://www.squeaksource.com/', aDirectoryName
	! !

!ScriptLoader class methodsFor: 'menu' stamp: 'LaurentLaffont 6/21/2010 22:50'!
menuCommandOn: aBuilder 
	<worldMenu> 
	
	(aBuilder item: #'Integrator Menu')
		order: 1.5;
		precondition: [self currentlyIntegratingChanges];
		parent: #System;  
		action: [ScriptLoader releaseMenu]! !

!ScriptLoader class methodsFor: 'private' stamp: 'sd 3/24/2008 20:59'!
packageToBeTestedFolderName

	^ 'packages-to-be-tested'! !

!ScriptLoader class methodsFor: 'public' stamp: 'damiencassou 7/2/2009 21:37'!
releaseMenu
	"self releaseMenu"
	|symbol|
	symbol := UIManager default
		chooseFrom: #('1- Prepare new update'
						'2- Done applying changes'
						'3- Verify new update (other image, same folder)'
						'4- Publish changes')
		values: #(prepareNewUpdate doneApplyingChanges verifyNewUpdate publishChanges).
	symbol ifNotNil: [ScriptLoader new perform: symbol]! !

!ScriptLoader class methodsFor: 'public' stamp: 'adrian-lienhard 6/6/2009 11:46'!
resetLogStream
	LogStream := nil! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
showIntegrationMenu

	CurrentlyIntegratingChanges := true.! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOne

	self currentMajorVersionNumber: 1.0! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOneDotOne

	self currentMajorVersionNumber: 1.1! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 5/14/2010 22:21'!
toPharoOneDotTwo

	self currentMajorVersionNumber: 1.2! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian-lienhard 6/6/2009 11:47'!
waitingCacheFolder
	^ (FileDirectory default directoryNamed: self packageToBeTestedFolderName)
		assureExistence;
		yourself

	! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 2/25/2010 18:22'!
CSForLastUpdate: aString
	"ScriptLoader new CSForLastUpdate: 'cleanUpMethods'"
	
	| str updateNumber filename|
	updateNumber := self getLatestUpdateNumber.
	filename := updateNumber asString, '-Pha-', aString, '.cs'.
	FileDirectory default 
		forceNewFileNamed:  filename
		do: [ :stream | 
					self 
						generateCS: self latestScriptLoaderPackageIdentificationString
						fromUpdate: updateNumber on: stream].
	^ filename! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2010 22:31'!
CSForLastUpdateAndPatchUpdatesList: aString
	"ScriptLoader new CSForLastUpdateAndPatchUpdatesList: 'cleanUpMethods'"
	| filename |
	filename := self CSForLastUpdate: aString.
	self updateUpdatesList: aString.
	^ filename ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addExtraRepositories
	
	"self new addExtraRepositories"
	
	self addRepository39ToAllPackages.
	self addRepository310ToAllPackages.
	self addRepositoryTaskForcesToAllPackages.
	self addRepositorySqueakTrunkToAllPackages.
	self addRepositoryMCToAllPackages.
	self addRepositoryTreatedToAllPackages.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:25'!
addHomeRepositoryToAllPackages
	"self new addHomeRepositoryToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository;
			 addRepository: self inboxRepository].
		
	MCRepositoryGroup default
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			 addRepository: self metacelloRepository.
	
		
	
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 17:40'!
addHomeRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 10/18/2009 16:11'!
addPackage: aString
	"to be tested" 
	
	| workingCopy |
	PackageInfo registerPackageName: aString.
	workingCopy := MCWorkingCopy forPackage: (MCPackage new name: aString)! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/13/2009 15:48'!
addRepository310ToAllPackages
	"self new addRepository310ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository310
			].
	
	! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/6/2009 17:38'!
addRepository39ToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepository39ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository39
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/14/2009 10:31'!
addRepositoryMCToAllPackages
	
	"self new addRepositoryMCToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryMC
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2009 20:47'!
addRepositorySqueakTrunkToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepositorySqueakTrunkToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositorySqueakTrunk
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/13/2009 15:59'!
addRepositoryTaskForcesToAllPackages
	"self new addRepositoryTaskForcesToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTaskForces
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 10/31/2005 18:01'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addRepositoryTreatedToAllPackages
	"self new addRepositoryTreatedToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTreated
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentDirtyPackages
	"ScriptLoader new allCurrentDirtyPackages"
	"return all the current dirty packages even the ones that we do not want to save"

	
	^  self allCurrentPackages select: [:each | each needsSaving].

	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentPackages
	"ScriptLoader new allCurrentPackages" 
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/1/2008 22:50'!
allCurrentVersions
	"self new allCurrentVersions"
	
	| copies names |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	names := copies collect:
		[:ea |  ea ancestry ancestorString ].
	^ names reject: #isEmpty! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 10/22/2009 22:41'!
announceOnMailingList
	"
	self new announceOnMailingList"
	|title|
	title := '[update ', CurrentMajorVersionNumber asString , '] #', self currentUpdateVersionNumber asString.
UIManager default
	edit: title, String cr, self currentUpdateVersionNumber asString, '
-----

', self commentForCurrentUpdate
	label: title.! !

!ScriptLoader methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
buildConfigurationMapFor: packageNames

	| configurationMap |
	configurationMap := MCConfiguration new.
	configurationMap repositories
		add: self repository;
		add: self inboxRepository.

	packageNames do: [:packageName | | version depArray |
		version := self loadVersionFromFileNamed: packageName.
		depArray := { version package name. version info name. version info id asString. }.
		configurationMap dependencies add: (MCConfiguration dependencyFromArray: depArray)].
	^configurationMap! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:32'!
checkImageIsUptodate

	| stream last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	stream := FileDirectory default oldFileNamed: 'updates.list'.
	stream contents linesDo: [ :each | last := each ].
	stream close.
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber ! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/7/2010 11:11'!
cleanUpForProduction
	"self new cleanUpForProduction"
	
	| oldDicts newDicts |
	
	"trim MC ancestory information"
	MCVersionInfo allInstances do: [ :each | each instVarNamed: 'ancestors' put: nil ].	

	"delete logo"	
	LogoImageMorph default: nil.

	"delete ScriptLoader log"
	ScriptLoader resetLogStream.

	(MCPackage named: 'HelpSystem') unload.
	Smalltalk globals at: #SUnitUnloader ifPresent:[ :unloader | unloader new unloadAll  ].

	"shrink method dictionaries."
	Smalltalk garbageCollect.
	oldDicts := MethodDictionary allInstances.
	newDicts := Array new: oldDicts size.
	oldDicts withIndexDo: [ :d :index | newDicts at: index put: d rehashWithoutBecome ].
	oldDicts elementsExchangeIdentityWith: newDicts.
	oldDicts := newDicts := nil.
	
	self removeDejaVuFonts.
	(MCPackage named: 'GraphicsResources') unload.
	
	(MCPackage named: 'HostMenus') unload.
	
	self cleanUpForRelease.
	(MCPackage named: self theScriptLoaderPackageName) unload.
	Smalltalk garbageCollect
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/14/2010 22:57'!
cleanUpForRelease
	"self new cleanUpForRelease"

	Author fullName: 'Mr.Cleaner'.
	DebuggerMethodMap withAllSubclassesDo: [ :each | each voidMapCache ].
	self cleanUpPackageOrganizer.
	self cleanUpMethods.
	DataStream initialize.
	Smalltalk cleanUpUndoCommands.
	GradientFillStyle initPixelRampCache.
	FreeTypeCache clearCurrent.
	ImageMorph classPool at: #DefaultForm put: (Form extent: 1 @ 1 depth: 1).
	Behavior flushObsoleteSubclasses.
	CommandHistory resetAllHistory.
	CommandHistory allInstancesDo: #initialize.
	MethodChangeRecord allInstancesDo: [ :x | x noteNewMethod: nil ].
	World cleanseOtherworldlySteppers.
	Smalltalk organization removeEmptyCategories.
	Browser initialize.
	SystemBrowser removeObsolete.
	AppRegistry removeObsolete.
	FileServices removeObsolete.
	MCFileBasedRepository flushAllCaches.
	MCMethodDefinition shutDown. 
	MCDefinition clearInstances.
	Smalltalk globals
		at: #TTFontDescription
		ifPresent: [ :c | 
			c
				clearDefault;
				clearDescriptions ].
	ExternalDropHandler resetRegisteredHandlers.
	Undeclared removeUnreferencedKeys.
	Smalltalk globals flushClassNameCache.
	ScrollBar initializeImagesCache.
	FreeTypeFontProvider current initialize.
	NaturalLanguageTranslator classPool at: #AllKnownPhrases put: nil.
	FreeTypeFontProvider current initialize.
	SystemNavigation default
		allObjectsDo: [ :each | 
			(each respondsTo: #releaseCachedState)
				ifTrue: [ each releaseCachedState ] ].
	3 timesRepeat: [ 
		Smalltalk garbageCollect.
		Symbol compactSymbolTable ].
	HashedCollection rehashAllSubInstances.
	
	"Remove empty categories, which are not in MC packages, because MC does
	not do this (this script does not make packages dirty)"
	Smalltalk organization removeEmptyCategories.
	Smalltalk
		allClassesAndTraitsDo: [ :class |
			[ :each |
				each
					removeEmptyCategories;
					sortCategories ]
						value: class organization;
						value: class class organization ].
	PackageOrganizer default packages
		do: [ :each | each methods ifEmpty: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'.
	Smalltalk organization sortCategories.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	Smalltalk garbageCollect.
	Author reset! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/5/2010 11:12'!
cleanUpMethods
	"Make sure that all methods in use are restarted"
	"ScriptLoader new cleanUpMethods"

	WeakArray restartFinalizationProcess.
	MethodChangeRecord allInstancesDo: [:x | x noteNewMethod: nil].
	WorldState allInstancesDo: [ :ws | ws convertAlarms; convertStepList; resetWorldMenu].
	WorldState allInstancesDo: [ :ws | ws instVarNamed: 'menuBuilder' put: nil ].
	ExternalDropHandler initialize.
	ScrollBar initializeImagesCache.
	GradientFillStyle initPixelRampCache.
	ProcessBrowser initialize.
	Smalltalk garbageCollect.
	Delay startTimerEventLoop! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 12/5/2009 11:19'!
cleanUpPackageOrganizer

	PackageOrganizer default packages
		do: [ :each | 
			each methods isEmpty
				ifTrue: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'! !

!ScriptLoader methodsFor: 'public' stamp: 'StephaneDucasse 8/21/2010 22:07'!
commentForCurrentUpdate
 ^ '- Issue 2839:	ContextInspector. Thanks Andreas Raab
- Issue 2840:	UUID class>>fromString36:. Thanks Nicolas Cellier.
	http://bugs.squeak.org/view.php?id=7262'! !

!ScriptLoader methodsFor: 'metacello-experiments' stamp: 'MarianoMartinezPeck 4/29/2010 23:37'!
compileMetacelloBaselineMethodSourceFrom:  aBaselineMethodName baselinePgramaName: aBaselinePgramaName
	
	ConfigurationOfPharoCore compile: 
		(self generateMetacelloBaselineMethodSourceFrom:  aBaselineMethodName baselinePgramaName: aBaselinePgramaName )
		classified: 'metacello - baselines'! !

!ScriptLoader methodsFor: 'metacello-experiments' stamp: 'MarianoMartinezPeck 4/29/2010 23:38'!
compileMetacelloVersionMethodSourceFrom:  aVersionMethodName aVersionPgramaName: aVersionPgramaName
	
	ConfigurationOfPharoCore compile: 
		(self generateMetacelloVersionMethodSourceFrom:  aVersionMethodName versionPgramaName: aVersionPgramaName )
		classified: 'metacello - versions'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 14:36'!
compileNewUpdateMethod
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethod)
		classified: 'pharo - updates'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 13:26'!
compileScriptMethodWithCurrentPackages: aNumber 
	"ScriptLoader new compileScriptMethodWithCurrentPackages: 9999"
	
	self class compile: 
		(self newGenerateScriptTemplateWithCurrentPackages: aNumber)
		classified: 'pharo - scripts'! !

!ScriptLoader methodsFor: 'utils' stamp: 'nice 1/5/2010 15:59'!
copyDiffPackagesToPharo
	"Copy the clean packages that may have been loaded by a slice but are not yet in pharo repository"
	"self new copyDiffPackagesToPharo"
	"self new diffPackages"
	

	| s man |
	s := Set new.
	man := MCWorkingCopy allManagers.
	Transcript show: '=========================================================================';cr.
	Transcript show: self diffPackages ;cr.
	self diffPackages do: 
		[:packName | | r | 
			r := man select: [:package |  packName, '*' match: package ancestry ancestorString].
			r isEmpty ifFalse: [s add: r first]].
	s do: [:wc | 
			self repository storeVersion: wc newVersion.].
		
	! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
copyPackagesFromWaitingFolderToHomeRepository
	"self defaultMCWaitingFolder allFileNames"
	"self new copyPackageFromWaitingFolderToHomeRepository"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		self repository storeVersion: version]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 3/18/2009 21:13'!
currentChangedPackages
	"self new currentChangedPackages" 
	
	^  self currentPackages select: [:each |
		each needsSaving or: [
			(PackagesBeforeLastLoad includes: each ancestry ancestorString) not ] ]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 6/12/2010 13:03'!
currentMajorVersionNumber

	^ self class currentMajorVersionNumber ! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 6/12/2010 13:07'!
currentMajorVersionNumberWithoutDot
	"self new currentMajorVersionNumberWithoutDot"
	^ self class currentMajorVersionNumber asString copyWithout: $.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'al 11/1/2008 19:49'!
currentPackages
	"self new currentPackages" 
	
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies reject: [:each |
		self packagesNotToSavePatternNames
			anySatisfy: [:p | p match: each package name]].
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:08'!
currentScriptVersionNumber
	^ CurrentScriptVersionNumber! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 9/8/2009 14:41'!
currentUpdateVersionNumber
	^ CurrentUpdateVersionNumber ifNil: [SystemVersion current highestUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 5/29/2006 20:52'!
currentVersions
	"ScriptLoader new currentVersions"
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies collect:
		[:ea |  ea ancestry ancestorString ]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'al 11/1/2008 19:49'!
currentVersionsToBeSaved
	"self new currentVersionsToBeSaved"
	
	^ self allCurrentVersions reject: [ :each |
		self packagesNotToSavePatternNames
			anySatisfy: [ :p | p match: each ] ]! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:46'!
deletePackage: aString

	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	MCWorkingCopy registry removeKey: toRemove package.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'stephane.ducasse 3/18/2009 21:13'!
diffPackages
	"return a list of packages that are new. They can be dirty or not."
	"self new diffPackages"
	 
	| diff |
	diff := Set new.
	self currentVersionsToBeSaved do: [:each |
		(PackagesBeforeLastLoad includes: each) ifFalse: [diff add: each]].
	^ diff
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 22:54'!
doneApplyingChanges
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	
	comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		centerAt: Sensor cursorPoint
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self].
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersion.
	self saveLatestScriptLoaderToWaitingFolder.
	
	self inform: 'Update prepared and ready to be verified.'! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 12:33'!
fixObsoleteReferences
	"self new fixObsoleteReferences"
	CompiledMethod allInstances
		do: [ :method | 
			| obsoleteBindings |
			obsoleteBindings := method literals
				select: [ :literal | literal isVariableBinding 
									and: [ literal value isBehavior and: [ literal value isObsolete ]] ].
			obsoleteBindings
				do: [ :binding | 
					| realClass obsName realName |
					obsName := binding value name.
					Transcript
						show: obsName;
						cr.
					realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
					realClass := Smalltalk globals at: realName asSymbol ifAbsent: [ UndefinedObject ].
					binding key: binding key value: realClass ] ].
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [ SystemNavigation default obsoleteBehaviors inspect ]! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 3/14/2010 12:44'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 8/14/2008 16:06'!
generateCS: packageInfo fromUpdate: updateNumber on: st
	
	st nextPutAll:
'"Postscript:
Leave the line above, and replace the rest of this comment by a useful one.
Executable statements should follow this comment, and should
be separated by periods, with no exclamation points (!!!!).
Be sure to put any further comments in double-quotes, like this one."

|repository|
repository := MCHttpRepository
                location: ''http://www.squeaksource.com/Pharo/''
                user: ''''
                password: ''''.
(repository loadVersionFromFileNamed:' .
	st nextPut: $' ; nextPutAll: packageInfo, '.mcz'') load.'; cr.
	st nextPutAll: 'ScriptLoader new update', (updateNumber) asString; nextPutAll: '.' ; cr.
	st nextPutAll: '!!'.
	^ st contents
! !

!ScriptLoader methodsFor: 'utils' stamp: 'stephane.ducasse 7/4/2009 12:27'!
generateCompleteFixList
	"generateCompleteFixList"
	| stream |
	stream := (FileStream newFileNamed: 'changes-log.txt').
	[ stream nextPutAll: ScriptLoader new logStream contents ] ensure: [ stream close ]! !

!ScriptLoader methodsFor: 'metacello-experiments' stamp: 'MarianoMartinezPeck 4/29/2010 23:38'!
generateMetacelloBaselineMethodSourceFrom:  aBaselineMethodName baselinePgramaName: aBaselinePgramaName
	
	| str withoutScriptLoader packageList |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: aBaselineMethodName asString, ': spec'; cr; cr.
	
	str nextPutAll: '<version: ', $' asString, aBaselinePgramaName asString , $' asString ,'>' ;  cr ; cr ; tab.
	str nextPutAll: 'spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do: [ '; cr; tab; tab.
	str nextPutAll: 'spec repository: ''http://www.squeaksource.com/Pharo''.'; cr.
	
	str nextPutAll: ''; tab; tab. 
	str nextPutAll: 'spec' ; cr.
	
	packageList := self getListPackagesForMetacelloBaseline:  self currentVersionsToBeSaved.
	packageList
		do: [ :each | str nextPutAll: '' ;  tab; tab ; tab. str nextPutAll: each]
		separatedBy: [str nextPutAll: $; asString; nextPut: Character cr].
	
	str nextPut: $]; nextPut: Character cr.
	^ str contents! !

!ScriptLoader methodsFor: 'metacello-experiments' stamp: 'MarianoMartinezPeck 4/29/2010 23:38'!
generateMetacelloVersionMethodSourceFrom:  aVersionMethodName versionPgramaName: aVersionPgramaName
	
	| str withoutScriptLoader packageList |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: aVersionMethodName asString, ': spec'; cr; cr.
	
	str nextPutAll: '<version: ', $' asString, aVersionPgramaName asString , $' asString ,'>' ;  cr ; cr ; tab.
	str nextPutAll: 'spec for: #common do: [ spec blessing: #release ].
	spec for: #pharo
		do: [ '; cr; tab; tab.
	str nextPutAll: 'spec repository: ''http://www.squeaksource.com/Pharo''.'; cr.
	
	str nextPutAll: ''; tab; tab. 
	str nextPutAll: 'spec' ; cr.
	
	packageList := self getListPackagesForMetacelloVersion:  self currentVersionsToBeSaved.
	packageList
		do: [ :each | str nextPutAll: '' ;  tab; tab ; tab. str nextPutAll: each]
		separatedBy: [str nextPutAll: $; asString; nextPut: Character cr].
	
	str nextPut: $]; nextPut: Character cr.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 8/30/2009 14:48'!
generateNewUpdateMethod
	"ScriptLoader new generateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, '.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:05'!
generateScriptAndUpdateMethodForNewVersion
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethod.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 14:41'!
generateScriptTemplateWithAllCurrentPackages
	"ScriptLoader new generateScriptTemplateWithAllCurrentPackages"
	
	| str |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'scriptXXX' ; cr ; cr ; tab.
	str nextPutAll: '| names|'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	self currentVersionsToBeSaved do: 
		[:each |
			str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 18:07'!
generateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '| names |'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'al 11/1/2008 18:15'!
getLatestScriptNumber
	"self new getLatestScriptNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'script*' match: each ].
	upfroms := upfroms collect: [:each | (each asString allButFirst: 6)].
	upfroms := upfroms reject: [:each | '*Log*' match: each ].
	upfroms := upfroms reject: [:each | '*XXX*' match: each ].
	upfroms := upfroms collect: [:each | each asNumber].
	^ upfroms asSortedCollection last
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 10/17/2009 12:33'!
getLatestUpdateNumber
	"self new getLatestUpdateNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'update*' match: each ].
	upfroms := upfroms collect: [:each | [(each asString last: 5) asNumber] on: Error do: [0]].
	^ upfroms asSortedCollection last! !

!ScriptLoader methodsFor: 'metacello-experiments' stamp: 'MarianoMartinezPeck 4/29/2010 23:38'!
getListPackagesForMetacelloBaseline:  aCollection
	^ (aCollection collect: [:each | each copyUpToLast: $-] ) collect: [:each| 'package: ', each surroundedBySingleQuotes].   ! !

!ScriptLoader methodsFor: 'metacello-experiments' stamp: 'MarianoMartinezPeck 4/29/2010 23:38'!
getListPackagesForMetacelloVersion:  aCollection
	^ aCollection collect: [:each| 'package: ',  (each copyUpToLast: $-) surroundedBySingleQuotes, ' with: [', each surroundedBySingleQuotes, ']'].   
	! !

!ScriptLoader methodsFor: 'accessing' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			self
				installGofer;
				gofer ]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'CarloTeixeira 8/11/2010 00:37'!
inboxRepository
	^ inboxRepository ifNil: [inboxRepository :=  MCHttpRepository inboxRepository]
	! !

!ScriptLoader methodsFor: 'initialize' stamp: 'stephane.ducasse 3/18/2009 21:13'!
initialize
	super initialize.
	PackagesBeforeLastLoad ifNil: [ PackagesBeforeLastLoad := Set new ]! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 7/10/2009 18:07'!
installGofer
	"self new installGofer"
	
	self class loadLatestPackage: 'Gofer' from: 'http://source.lukas-renggli.ch/flair'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 14:46'!
installRepository: aString for: packageName

	(MCWorkingCopy allManagers select: [:each | each package name = packageName])
		first repositoryGroup
		addRepository: (MCHttpRepository new location: aString ; user: '' ; password: '')
		! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'alain.plantec 2/6/2009 15:49'!
installVersionInfo
	"self new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' translated initialAnswer: '3.9' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	
! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 3/14/2010 21:13'!
installingInstaller
	"self new installingInstaller"

	| mc files fileToLoad version |
	mc := Smalltalk globals
		at: #MCHttpRepository
		ifPresent: [ :repoClass | repoClass location: 'www.squeaksource.com/Installer' user: 'squeak' password: 'squeak' ].
	files := mc readableFileNames
		asSortedCollection: [ :a :b | 
			[ (a findBetweenSubStrs: #($.)) allButLast last asInteger > (b findBetweenSubStrs: #($.)) allButLast last asInteger ]
				on: Error
				do: [ :ex | false ] ].
	fileToLoad := files detect: [ :aFile | aFile beginsWith: 'Installer-Core' ] ifNone: [ nil ].
	version := mc versionFromFileNamed: fileToLoad.
	version workingCopy repositoryGroup addRepository: mc.
	mc creationTemplate: mc asCreationTemplate.
	version load.
	^ Smalltalk globals at: #Installer! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 8/14/2008 16:03'!
latestScriptLoaderPackageIdentificationString
	"ScriptLoader new latestScriptLoaderPackageIdentificationString"
	
	^  self allCurrentVersions detect: [:each | 'ScriptLoader*' match: each ]
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 9/8/2009 21:52'!
launchUpdate

	Utilities updateFromServer! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:06'!
loadLatestScriptloader
	"self new loadLatestScriptloader"
	
	self class 
		loadLatestPackage: 'ScriptLoader', self currentMajorVersionNumberWithoutDot 
		fromSqueaksource: 'Pharo' 
	

! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 7/7/2010 23:22'!
loadLatestUpdateList
	
	| listToUse lastUpdate |
	"Use the largest we find (on the assumption that contains the most
	listings and is thus up to date)" 
	listToUse :=
		((Utilities serverUrls
			collect: [:url | (HTTPClient httpGet: 
				url , 'updates/pharo' , self class currentMajorVersionNumber asString , '/' , 'updates.list') 					
					contents])
			sort: [:each | each size]) first.
				
	listToUse linesDo: [:each | lastUpdate := each].
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			FileDirectory default
				forceNewFileNamed: 'updates.list'
				do: [:stream | stream nextPutAll: listToUse]]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'nice 1/5/2010 15:59'!
loadOneAfterTheOther: aCollection merge: aBoolean
	
	(self newerVersionsIn: aCollection)
		do: [:fn | | loader |
			loader := aBoolean
				ifTrue: [ MCVersionMerger new ]
				ifFalse: [ MCVersionLoader new].
			loader addVersion: (self repository loadVersionFromFileNamed: fn).
			aBoolean
				ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
							request merger conflicts isEmpty
								ifTrue: [request resume: true]
								ifFalse: [request pass]]]
				ifFalse: [loader load]]
  	  	displayingProgress: 'Loading versions...'.
	

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'adrian_lienhard 2/21/2009 13:40'!
loadOneAfterTheOther: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadOneAfterTheOther: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			self loadOneAfterTheOther: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
loadPackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		version load]! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'michael.rueger 1/13/2009 15:26'!
loadTogether: aCollection merge: aBoolean
	| loader |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	(self newerVersionsIn: aCollection)
		do: [:fn | loader addVersion: (self loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader hasVersions ifTrue: [loader load]]

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 5/10/2008 12:41'!
loadTogether: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadTogether: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			 self loadTogether: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'private' stamp: 'michael.rueger 1/13/2009 15:25'!
loadVersionFromFileNamed: fn
	| version |
	version := self repository loadVersionFromFileNamed: fn.
	^version
		ifNil: [self inboxRepository loadVersionFromFileNamed: fn]! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 4/4/2008 14:47'!
log: aString

	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/15/2008 18:30'!
logContents

	^ self logStream contents! !

!ScriptLoader methodsFor: 'log' stamp: 'adrian_lienhard 3/16/2009 21:30'!
logStream
	^ LogStream ifNil: [
		LogStream := ReadWriteStream on: (String new: 1000)]! !

!ScriptLoader methodsFor: 'private' stamp: 'stephane.ducasse 3/18/2009 21:13'!
markPackagesBeforeNewCodeIsLoaded
	"Use this method to keep a log of all the packages that were loaded before loading new code. This will help the system to perform a diff and know after what to publish."
	
	"self new markPackagesBeforeNewCodeIsLoaded"
	
	PackagesBeforeLastLoad := self currentVersionsToBeSaved! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
mergePackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles
		do: [ :name | | version |
			version := self class defaultMCWaitingFolder  versionFromFileNamed: name.
			version merge.
			]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'AdrianLienhard 6/5/2010 11:08'!
metacelloRepository
	^ (MCHttpRepository 
		location: 'http://www.squeaksource.com/MetacelloRepository'
		user: ''
		password: '')
	! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:35'!
newGenerateNewUpdateMethod
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:25'!
newGenerateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	"this version change the script to only "
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '^ '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr'.
	^ str contents! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 10/13/2005 21:44'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		MCWorkingCopy allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ScriptLoader methodsFor: 'utils' stamp: 'sd 2/4/2008 16:09'!
openWindow: contents label: aLabel

	StringHolder new 
		contents: contents ;
		openLabel: aLabel! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 7/17/2010 13:35'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'AST*'
			'*Refactoring*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
			'*OB-*'
			'OmniBrowser*'
		).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:23'!
prepareNewUpdate
	self launchUpdate.
	self loadLatestScriptloader.
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodate ifFalse: [self loadLatestUpdateList].
	self checkImageIsUptodate ifFalse: [
		^ self inform: 'Your update.list and your image are not in sync!! Please use a fresh image and download the latest update.list and start over. May be you are doing a rollback and you should remove the bogus ScriptLoader version from the Pharo repository' ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	self inform: 'The new version number is ' , self currentUpdateVersionNumber asString , '. Ready to apply changes now.', String cr, 'You are now running in image ', (FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName)).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 21:07'!
publishChanges
	| username password changescriptname changesetFilename str strings|
	(FileStream isAFileNamed: 'PharoPass.txt') 
		ifTrue: [ str := FileStream fileNamed:  'PharoPass.txt'. 
				strings := str contents substrings.
				username := strings first.
				password := strings second] 
		ifFalse: [ username := UIManager default request: 'Pharo repository login'.
			     password := UIManager default requestPassword: 'Pharo repository password'.].

	self setToRepositoriesPassword: password to: username.
	
	changescriptname := UIManager default request: 'Changeset name (no space)' initialAnswer: 'WhatAsChanged'.
	changesetFilename := self CSForLastUpdateAndPatchUpdatesList: changescriptname.
	self copyPackagesFromWaitingFolderToHomeRepository.
	self announceOnMailingList.
	self inform: 'All packages have been uploaded to the Pharo repository.
Remaining manual steps:
1) ./upFiles ',changesetFilename,'
2) ./upFiles updates.list
3) Announce new update on mailing list'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:22'!
removeAllRepositories
	"self new removeAllRepositories"
	
	MCWorkingCopy allManagers do: [:each |  each  repositoryGroup initialize].
	MCRepositoryGroup default initialize.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:19'!
removeAllRepositories: aColl
	"self new removeAllRepositories: 
			#('http://source.squeakfoundation.org/inbox/'
			 'http://source.squeakfoundation.org/39a/'
			 'http://source.squeakfoundation.org/Balloon/'
			 'http://source.squeakfoundation.org/Compression/'
			 'http://source.squeakfoundation.org/Graphics/'
			  'http://source.wiresong.ca/mc/')"
 
	
	MCWorkingCopy allManagers do: [:each | 
		aColl
			do: [:location | 
					each  repositoryGroup removeHTTPRepositoryLocationNamed: location]].
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 13:16'!
removeDejaVuFonts
	"Note, you need to close all windows to make the Deja Vu fonts being GCed"

	StandardFonts setDefaultFonts: #(
		(defaultFont: 'Accuny' 10)
		(codeFont: 'Accuny' 10)
		(listFont: 'Accuny' 10)
		(menuFont: 'Accuny' 10)
		(windowTitleFont: 'Accuny' 10)
		(balloonFont: 'Accuny' 10)
		(buttonFont: 'Accuny' 10)).
	TextConstants removeKey: 'Bitmap DejaVu Sans'! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:06'!
removeScriptMethods
	"self new removeScriptMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - scripts') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:04'!
removeUpdateMethods

	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - updates') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:41'!
repository
	^ repository ifNil: [
		repository := MCHttpRepository new
			location:  'http://www.squeaksource.com/Pharo';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:48'!
repository310
	^ repository310 ifNil: [
		repository310 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/310';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repository39
	^ repository39 ifNil: [
		repository39 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/39a';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:42'!
repository: aRepository
	repository := aRepository! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/14/2009 10:32'!
repositoryMC
	^ repositoryMC ifNil: [
		repositoryMC := MCHttpRepository new
			location:  'http://source.wiresong.ca/mc';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repositorySqueakTrunk
	^ repositorySqueakTrunk ifNil: [
		repositorySqueakTrunk := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/trunk';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:59'!
repositoryTaskForces
	^ repositoryTaskForces ifNil: [
		repositoryTaskForces := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTaskForces';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/26/2009 07:47'!
repositoryTreated
	^ repositoryTreated ifNil: [
		repositoryTreated := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTreatedInbox';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'private' stamp: 'stephane.ducasse 3/18/2009 21:13'!
resetPackagesBeforeLastLoad
	PackagesBeforeLastLoad := Set new! !

!ScriptLoader methodsFor: 'private' stamp: 'DamienCassou 9/8/2009 14:42'!
saveAsNewImageWithCurrentReleaseName
	|name|
	name := FileDirectory default
				nextNameFor: ('releasePharo-',  self currentUpdateVersionNumber asString)
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 1/31/2010 22:16'!
saveAsNewImageWithCurrentReleaseNameToPublish
	"If the reload failed and you do not want to lose
	time reload all the cs and packages... you can now restart from the image saved now"
	|name|
	name := FileDirectory default
				nextNameFor: ('releasePharoToPublish-',  self currentUpdateVersionNumber asString)
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'al 11/1/2008 18:33'!
saveChangedPackagesIntoWaitingFolder
	self currentChangedPackages do: [:each |
		self
			saveInToReloadCachePackage: each
			with: self commentForCurrentUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/2/2008 00:31'!
saveInToReloadCachePackage: aWorkingCopy with: aMessageString
	self
		savePackage: aWorkingCopy
		in: self class defaultMCWaitingFolder
		with: aMessageString! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/28/2010 20:06'!
saveLatestScriptLoaderToHome
	"self new saveLatestScriptLoaderToHome"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader*' match: each  package name].
	self repository storeVersion: r first newVersion.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:31'!
saveLatestScriptLoaderToWaitingFolder
	"self new saveLatestScriptLoaderToWaitingFolder"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader', self currentMajorVersionNumberWithoutDot, '*' match: each  package name].
	self
		saveInToReloadCachePackage: r first
		with: self commentForCurrentUpdate! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 10/20/2009 11:28'!
savePackage: aWorkingCopy in: aRepository with: aMessageString
	" | sc |
	  sc := self new.
	  sc savePackage: (self new workingCopyFromPackageName: 'ScriptLoader11') 
		in: MCCacheRepository default
		with: 'this is test to automate dirty package saving in cache'"

	aRepository storeVersion: (aWorkingCopy 
		newVersionWithName: aWorkingCopy uniqueVersionName
		message: aMessageString)! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 13:21'!
script0! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 13:34'!
script1

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.52.mcz
Collections-Strings-MarcusDenker.125.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.476.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-MarcusDenker.47.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.28.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.152.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.250.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.39.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-MarcusDenker.689.mcz
KernelTests-MarcusDenker.264.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.619.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.178.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-MarcusDenker.42.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.50.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.32.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-MarcusDenker.35.mcz
NetworkTests-StephaneDucasse.30.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-MarcusDenker.133.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.9.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.68.mcz
System-Clipboard-StephaneDucasse.16.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-MarcusDenker.49.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.97.mcz
System-Platforms-StephaneDucasse.7.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-MarcusDenker.302.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-MarcusDenker.176.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.407.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-StephaneDucasse.372.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/22/2010 18:45'!
script10

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.56.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.628.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.29.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.196.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.53.mcz
ToolBuilder-Morphic-StephaneDucasse.77.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/21/2010 22:08'!
script100

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.15.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 18:32'!
script11

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.629.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.32.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 20:23'!
script12

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.630.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.34.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.188.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 21:02'!
script13

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.695.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.630.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.36.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.188.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 22:52'!
script14

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.695.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.38.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.190.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/27/2010 18:24'!
script15

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.696.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.40.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.309.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/27/2010 22:15'!
script16

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.42.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.409.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 15:28'!
script17

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.182.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.44.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.409.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 15:49'!
script18

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.183.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.46.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.409.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 16:40'!
script19

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.183.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.48.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.410.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 15:16'!
script2

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.52.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.477.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.28.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.152.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.250.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.39.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-MarcusDenker.689.mcz
KernelTests-MarcusDenker.264.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.620.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.178.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-MarcusDenker.42.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.50.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.32.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-MarcusDenker.35.mcz
NetworkTests-StephaneDucasse.30.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-MarcusDenker.133.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.11.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.68.mcz
System-Clipboard-StephaneDucasse.16.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-MarcusDenker.49.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.97.mcz
System-Platforms-StephaneDucasse.7.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-MarcusDenker.302.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.177.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.407.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-StephaneDucasse.372.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 20:08'!
script20

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.183.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.410.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/30/2010 21:41'!
script21

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.59.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-Display Objects-StephaneDucasse.4.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.4.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.701.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.54.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.313.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.3.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/30/2010 23:11'!
script22

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.59.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.1.mcz
Graphics-Display Objects-StephaneDucasse.4.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.4.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.701.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.2.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.314.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.3.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/1/2010 00:04'!
script23

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.702.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/2/2010 13:09'!
script24

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.97.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-MarcusDenker.703.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.192.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 15:54'!
script25

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-MarcusDenker.703.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.249.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.192.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 16:10'!
script26

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-MarcusDenker.703.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.249.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.192.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 16:55'!
script27

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.100.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.255.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.705.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.642.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.194.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.415.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 17:22'!
script28

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.100.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.255.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.642.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.194.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.415.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 19:20'!
script29

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.100.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.643.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.194.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.416.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/12/2010 15:32'!
script3

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.52.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.477.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.28.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.152.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.250.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.39.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-MarcusDenker.689.mcz
KernelTests-MarcusDenker.264.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.620.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.178.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-MarcusDenker.42.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.50.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.32.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-MarcusDenker.35.mcz
NetworkTests-StephaneDucasse.30.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-MarcusDenker.133.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-MarcusDenker.13.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.68.mcz
System-Clipboard-StephaneDucasse.16.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-MarcusDenker.49.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.97.mcz
System-Platforms-StephaneDucasse.7.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-MarcusDenker.302.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-MarcusDenker.178.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.407.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/3/2010 22:27'!
script30

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.643.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.416.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/4/2010 23:24'!
script31

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.643.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.416.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/5/2010 16:07'!
script32

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-MarcusDenker.644.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-MarcusDenker.251.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.417.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/6/2010 09:05'!
script33

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-MarcusDenker.644.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-MarcusDenker.251.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.418.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/6/2010 09:47'!
script34

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-MarcusDenker.644.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-MarcusDenker.251.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.418.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/6/2010 20:39'!
script35

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.707.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-MarcusDenker.645.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.2.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.252.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.140.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.419.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/7/2010 18:59'!
script36

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.708.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-MarcusDenker.645.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.2.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.252.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.140.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.419.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/7/2010 19:14'!
script37

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.257.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.8.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.646.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.252.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/7/2010 23:13'!
script38

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.257.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.8.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.646.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.254.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2010 00:11'!
script39

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.258.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.646.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.254.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 16:04'!
script4

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.54.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.30.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.251.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.690.mcz
KernelTests-StephaneDucasse.265.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.621.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.15.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-StephaneDucasse.303.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.179.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2010 15:26'!
script40

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.258.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/10/2010 18:00'!
script41

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.258.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.142.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.22.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/10/2010 18:44'!
script42

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.142.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.22.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.197.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 16:22'!
script43

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.197.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 18:43'!
script44

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.472.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.197.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 18:53'!
script45

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.472.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.649.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 23:08'!
script46

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.649.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/17/2010 13:39'!
script47

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.651.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.257.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.82.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/17/2010 15:29'!
script48

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.651.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.257.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.82.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/17/2010 16:02'!
script49

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 23:08'!
script5

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.54.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.251.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.690.mcz
KernelTests-StephaneDucasse.265.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.622.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.17.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-StephaneDucasse.306.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.180.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 11:07'!
script50

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.37.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 11:14'!
script51

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.38.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 11:22'!
script52

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 12:12'!
script53

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.655.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.261.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.86.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 12:56'!
script54

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.655.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.261.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.87.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 13:48'!
script55

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.656.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.262.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 14:24'!
script56

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.656.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.263.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 15:25'!
script57

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.711.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.657.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.263.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.422.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 17:07'!
script58

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.711.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.661.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.422.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/19/2010 22:58'!
script59

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.711.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.661.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.424.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/13/2010 15:09'!
script6

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.54.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.251.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.691.mcz
KernelTests-StephaneDucasse.266.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.624.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-StephaneDucasse.306.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.180.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/21/2010 18:12'!
script60

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.712.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.425.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/23/2010 12:37'!
script61

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.712.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.425.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/23/2010 21:22'!
script62

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.712.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.426.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/26/2010 12:44'!
script63

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.713.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/27/2010 09:47'!
script64

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.713.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.663.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.268.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/27/2010 15:05'!
script65

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.715.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.663.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.269.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/29/2010 20:46'!
script66

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.161.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.715.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.663.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.270.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.89.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/29/2010 22:05'!
script67

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.161.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.715.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.664.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.271.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.89.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.428.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/31/2010 19:58'!
script68

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.163.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.666.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.271.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.428.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/1/2010 13:20'!
script69

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.163.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.667.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.271.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.429.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/13/2010 16:10'!
script7

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.53.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.692.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.624.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.21.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.193.mcz
System-Support-StephaneDucasse.306.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.16.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.181.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/1/2010 21:57'!
script70

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.163.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.261.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.667.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.272.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.203.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.429.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/2/2010 23:16'!
script71

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.165.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.261.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.58.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.667.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.108.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.203.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.429.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 14:31'!
script72

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.165.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.263.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.58.mcz
Kernel-StephaneDucasse.719.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.670.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.203.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.431.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 15:15'!
script73

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.166.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.720.mcz
KernelTests-StephaneDucasse.275.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.10.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.325.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.204.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 17:33'!
script74

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.166.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.721.mcz
KernelTests-StephaneDucasse.275.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.11.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 18:51'!
script75

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.168.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.723.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.12.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 19:47'!
script76

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.168.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.12.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 23:04'!
script77

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.6.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.6.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.13.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/4/2010 11:57'!
script78

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.674.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/4/2010 13:06'!
script79

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.674.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/19/2010 12:31'!
script8

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.53.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.692.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.626.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.23.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.193.mcz
System-Support-StephaneDucasse.307.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/5/2010 15:29'!
script80

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-MarcusDenker.675.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/8/2010 18:49'!
script81

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.676.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.33.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.328.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/9/2010 17:09'!
script82

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.676.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-MarcusDenker.11.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.10.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.328.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/10/2010 21:41'!
script83

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.676.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.13.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.274.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.328.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.435.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/10/2010 22:33'!
script84

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.278.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.678.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.13.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.330.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.207.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.435.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/11/2010 12:50'!
script85

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.267.mcz
Graphics-Display Objects-StephaneDucasse.9.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.726.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-StephaneDucasse.679.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.330.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.207.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.436.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/14/2010 23:12'!
script86

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.104.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.142.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-MarcusDenker.41.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.268.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.680.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.437.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 11:10'!
script87

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-MarcusDenker.41.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.268.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.438.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 13:01'!
script88

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.42.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.269.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.7.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.438.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 13:41'!
script89

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.438.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/21/2010 22:40'!
script9

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.53.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.626.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.25.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.193.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 19:18'!
script90

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.728.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.439.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.378.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/16/2010 09:12'!
script91

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.729.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.378.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/16/2010 15:32'!
script92

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.730.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.71.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'stephaneducasse 8/16/2010 23:24'!
script93

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.71.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/17/2010 20:12'!
script94

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.71.mcz
Morphic-StephaneDucasse.683.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.279.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/18/2010 11:42'!
script95

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.684.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.279.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/19/2010 11:23'!
script96

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.684.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.280.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/19/2010 22:39'!
script97

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.685.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.333.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/20/2010 11:55'!
script98

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.686.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.333.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/20/2010 22:30'!
script99

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.15.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:43'!
setToRepositoriesPassword: aPassword to: aUser
	"self new setToRepositoriesPassword: '' to: ''"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllRepositories: {self repository locationWithTrailingSlash . self inboxRepository locationWithTrailingSlash}. 
	self repository password: aPassword.
	self repository user: aUser.
	self inboxRepository password: aPassword.
	self inboxRepository user: aUser.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:07'!
setUpdateAndScriptVersionNumbers
	CurrentUpdateVersionNumber := self getLatestUpdateNumber + 1.
	CurrentScriptVersionNumber := self getLatestScriptNumber + 1.! !

!ScriptLoader methodsFor: 'accessing' stamp: 'MarcusDenker 3/11/2010 19:58'!
theScriptLoaderPackageName
	^'ScriptLoader11'! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:58'!
unloadPackage: aString
	"self new unloadPackage: 'Sixx'"
	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'stephane.ducasse 2/6/2009 17:36'!
unloadPackageNamed: aString
	"self new workingCopyFromPackageName: 'CollectionExtensions' "
	
	^ (self workingCopyFromPackageName: aString) unload
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 7/15/2006 20:39'!
unloadPackages
	"ScriptLoader new unloadPackages"
	
	| copies namesOfpackagesToUnload |
	namesOfpackagesToUnload := self packagesToUnload. 
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	(copies select: [:each | namesOfpackagesToUnload anySatisfy: [:ea | ea match: each package name ]])
		do: [:z | z unload].! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 13:09'!
update11202

	"place holder"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 13:21'!
update12002

	"place holder"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 13:35'!
update12003
	"self new update12003"
	self withUpdateLog: 'Issue 2503:	Remove add viewing'.
	self loadTogether: self script1 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 15:16'!
update12004
	"self new update12004"
	self withUpdateLog: '- ScriptLoaderTest fixes
- Issue 2487: Morph cleaning
- Issue 2455: testIsAllDigits'.
	self loadTogether: self script2 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/12/2010 15:32'!
update12005
	"self new update12005"
	self withUpdateLog: 'Redo the changes of 11400:
Issue 2548:	NewTestMorphTests>>#testAcceptContents fails
Issue 2547:	FilesStreamTest>>testPositionPastEndIsAtEnd
Issue 2506:	Browsing hierarchy of Traits crashes OB'.
	self loadTogether: self script3 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 16:04'!
update12006
	"self new update12006"
	self withUpdateLog: '- Issue 1795:	look for squeak everywhere. Thanks Veronica'.
	self loadTogether: self script4 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 23:08'!
update12007
	"self new update12007"
	self withUpdateLog: '- Issue 2290: new windows (e.g. workspaces) appear wherever they feel like
- SystemChangeNotifier-Tests from 3.9. 
- Issue 2381: We should probably remove slideToTrash'.
	self loadTogether: self script5 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/13/2010 15:09'!
update12008
	"self new update12008"
	self withUpdateLog: '- 2990: fix a bug which make selection of strategy does not work. --> this is an old code for testing, which I lost.

2422 Removed
- isolationSet and thisDefinition (instances variables never used) 
- methods reassigning isolationSet also removed (as it was never initialized)

- TestSubclass '.
	self loadTogether: self script6 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/13/2010 16:11'!
update12009
	"self new update12009"
	self withUpdateLog: 'Partial cleanup for 2204 
Rewrite plenty of Smalltalk at:  as Smalltalk globals at: '.
	self loadTogether: self script7 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/19/2010 12:32'!
update12010
	"self new update12010"
	self withUpdateLog: '- Issue 2556:	AutoStart
- Issue 2557:	NewTextMorph and CodeMorphs refactorings and tests'.
	self loadTogether: self script8 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/21/2010 22:40'!
update12011
	"self new update12011"
	self withUpdateLog: '- Issue 2555:	WideString asByteString does not return a ByteString. Thanks Henrik!!
- Issue 2580: COG	primitive:error: pragma does not work. Thanks Eliot/Henrik
- Issue 2581: COG	Float access methods
- Issue 2579:	Necessary Image Changes For Cog To Work
	'.
	self loadTogether: self script9 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/22/2010 18:46'!
update12012
	"self new update12012"
	self withUpdateLog: '- Issue 2582:	Rearrange World Menu
- Issue 2069:	Be able to load DummyUIManager in a Pharo image'.
	self loadTogether: self script10 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 18:20'!
update12013
	"self new update12012"
	"placeholder to rsync with the update"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 18:36'!
update12014
	"self new update12014"
	self withUpdateLog: '- Issue 2582:	Rearrange World Menu'.
	self loadTogether: self script11 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 20:25'!
update12015
	"self new update12015"
	self withUpdateLog: '- Issue 2554:	SystemWindow>>embeddable defect. Thanks Hilaire
- Issue 2547:	FilesStreamTest>>testPositionPastEndIsAtEnd	
- Issue 2546:	Tests failing: BlockClosureTest and MessageTallyTest'.
	self loadTogether: self script12 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 21:04'!
update12016
	"self new update12016"
	self withUpdateLog: '- Issue 2413:	cmd-b and cmd-m with fallbacks
- Issue 2069:	Be able to load DummyUIManager in a Pharo image	
- Issue 2528:	test commenting and cleaning'.
	self loadTogether: self script13 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 22:53'!
update12017
	"self new update12017"
	self withUpdateLog: '- Issue 2585:	Missing menus in Mac host menu. Thanks Laurent
- Issue 2576:	Adding auto fit to NewTextMorph (new version). Thanks Fernando
- Issue 2589:	TestCase >> should: notTakeMoreThan: not working well with asserts in block
	Changes should: notTakeMoreThan: so the evaluated block if it raises exceptions does not cause a timeout assertion failure, but rather a failure appropriate for the exception which occurred.
This means such errors no longer causes opening of debuggers when running a test batch, and that when selecting the failed test, the debugger opens on the relevant failure. Thanks Henrik.'.
	self loadTogether: self script14 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/27/2010 18:24'!
update12018
	"self new update12018"
	self withUpdateLog: '-  Issue 2593:	SystemNavigation#allSendersOf: returns inexisting references
	
- Issue 2480:	make and:and:and:and: and and:and: deprecated'.
	self loadTogether: self script15 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/27/2010 22:15'!
update12019
	"self new update12019"
	self withUpdateLog: '- Issue 156: Pointer tracing tools do not consistently find pointers. Thanks andy, johan and matthew.'.
	self loadTogether: self script16 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 15:28'!
update12020
	"self new update12020"
	self withUpdateLog: '- Issue-2448-WideStringDisplayMangled. Part one'.
	self loadTogether: self script17 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 15:49'!
update12021
	"self new update12021"
	self withUpdateLog: 'Issue-2448-WideStringDisplayMangled. Part Two of slice, now with inst var in super, and refactored methods.
Part ONE (ie version 3) needs to be loaded before this one.
(ie. this is needs two separate patches)'.
	self loadTogether: self script18 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 16:42'!
update12022
	"self new update12022"
	self withUpdateLog: '-  Issue 2597:	Versions Browser diff checkboxes'.
	self loadTogether: self script19 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 20:08'!
update12023
	"self new update12023"
	self withUpdateLog: '- Issue 2577:	Duplicate primInitializeNetwork: method'.
	self loadTogether: self script20 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/30/2010 21:41'!
update12024
	"self new update12024"
	self withUpdateLog: '- Issue 2105:	Packages remodularization'.
	self loadTogether: self script21 merge: false.
	(MCPackage named: 'Announcements') workingCopy unregister.
(MCPackage named: 'Graphics') workingCopy unregister.
(MCPackage named: 'GraphicsTests') workingCopy unregister.
(MCPackage named: 'GraphicsResources') workingCopy unregister.
(MCPackage named: 'Multilingual') workingCopy unregister.
(MCPackage named: 'MultilingualTests') workingCopy unregister.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/30/2010 23:11'!
update12025
	"self new update12025"
	self withUpdateLog: '- Issue 2599:	better extract parameter
- Issue 2604:	a script as argument
       squeak mysqueak.image file.st
       squeak mysqueak.image scripts/file.st
       squeak mysqueak.image ../../svn/scripts/file.st'.
	self loadTogether: self script22 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/1/2010 00:04'!
update12026
	"self new update12026"
	self withUpdateLog: '- Issue 2069:	Be able to load DummyUIManager in a Pharo image. Part two'.
	self loadTogether: self script23 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/2/2010 13:09'!
update12027
	"self new update12027"
	self withUpdateLog: 'Issue 2612:	DateAndTime current asUnixTime walkback in 1.1 rc3
Issue 2588:	Dictionary>>do:
Issue 2598:	Trait composition with exclusion lost when loading package from MC'.
	self loadTogether: self script24 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 15:54'!
update12028
	"self new update12028"
	self withUpdateLog: '- Issue 2615:	Use overflow rows for ToolBuilder button panels. Thanks Gary!!
- Issue 2616:	Use overflow rows for Debugger custom buttons.
Thanks Gary!!
-  Issue 2624:	Much faster Dictionary>>unreferencedKeys. Thanks Eliot'.
	self loadTogether: self script25 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 16:10'!
update12029
	"self new update12029"
	self withUpdateLog: '- Issue 2625:	Symbol class>>selectorsContaining:. Thanks Eliot'.
	self loadTogether: self script26 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 16:55'!
update12030
	"self new update12030"
	self withUpdateLog: '- Issue 2596:	More cull: usage. Thanks henrik'.
	self loadTogether: self script27 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 17:22'!
update12031
	"self new update12031"
	self withUpdateLog: '- Issue 2307:	Block should display their code
- Issue 2584:	COG- LargeNegativeInteger to be compact at 5'.
	self loadTogether: self script28 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 19:20'!
update12032
	"self new update12032"
	self withUpdateLog: '- Issue 2613:	remove PopUpMenu SelectionMenu CustomMenu'.
	self loadTogether: self script29 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/3/2010 22:27'!
update12033
	"self new update12033"
	self withUpdateLog: '- Issue 2636:	Collection>>ifNotEmpty: and ifEmpty: better comment and more explitcit definition
- Issue 2483: test to check that temp are nil out'.
	self loadTogether: self script30 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/4/2010 23:25'!
update12034
	"self new update12034"
	self withUpdateLog: '-  Issue 2638:	DNU does not open a debugger. 
Thanks pavel :) We are allowed to break the system to improve it ok after we have to help to repair it :)'.
	self loadTogether: self script31 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/5/2010 16:07'!
update12035
	"self new update12035"
	self withUpdateLog: 'Issue 2639:	Tidy up of MessageNames tool
Issue 1498:	FileList will not allow you to delete a directory?'.
	self loadTogether: self script32 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/6/2010 09:05'!
update12036
	"self new update12036"
	self withUpdateLog: 'Issue 2640:	Adding remote server uses deprected API
Issue 2641:	File already exists dialog has a missing space
Issue 2643:	Read ftp file with remote server using FileList crashes with DNU
Issue 2642:	Improve the PopupChoiceDialogWindow/PopupChoiceOrRequestDialogWindow'.
	self loadTogether: self script33 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/6/2010 09:48'!
update12037
	"self new update12037"
	self withUpdateLog: 'Issue 2590:	Remove PreferenceBrowser package
Issue 2645:	Remove System Package'.
	self loadTogether: self script34 merge: false.
	(MCPackage named: 'System') workingCopy unregister.
(MCPackage named: 'PreferenceBrowser') workingCopy unregister
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/6/2010 20:41'!
update12038
	"self new update12038"
	self withUpdateLog: 'Issue 2648:	LanguageEnvironment>>setupSqueaklandSpecifics
Issue 2647:	Consistency by providing uppercase menu items in Tools menus
Issue 2649:	World tasklist navigation
Issue 2644:	DateAndTime>>asUnixTime should ignore timezones?'.
	self loadTogether: self script35 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/7/2010 19:00'!
update12039
	"self new update12039"
	self withUpdateLog: 'Issue 2635: Preparation. '.
	self loadTogether: self script36 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/7/2010 19:15'!
update12040
	"self new update12040"
	self withUpdateLog: 'Issue 2635: Uppercase extensions - first mail. '.
	self loadTogether: self script37 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/7/2010 23:13'!
update12041
	"self new update12041"
	self withUpdateLog: '- Issue 2642:	Improve the PopupChoiceDialogWindow/PopupChoiceOrRequestDialogWindow'.
	self loadTogether: self script38 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2010 00:12'!
update12042
	"self new update12042"
	self withUpdateLog: '- Issue 2657:	some Point enhancements'.
	self loadTogether: self script39 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2010 15:26'!
update12043
	"self new update12043"
	self withUpdateLog: '- Issue 2595:	Changing color/fillStyle by morph halo menu'.
	self loadTogether: self script40 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/10/2010 18:00'!
update12044
	"self new update12044"
	self withUpdateLog: '- Issue 2652:	better flush of class name cache when removing key
- Issue 2568:	Remove ancient j3 support	
- Issue 2650:	Easier doit of commented expresson'.
	self loadTogether: self script41 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/10/2010 18:44'!
update12045
	"self new update12045"
	self withUpdateLog: '- Issue 2300:	ServerDirectory cleanup	
- Issue 2226:	shuffled and shuffle
- Issue 2238:	tests for FileStream behavior.
- Issue 2129:	Cursor with Alpha from OLPC
	CursorWithAlpha biggerNormal showWhile:[Sensor waitButton]. '.
	self loadTogether: self script42 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 16:49'!
update12046
	"self new update12046"
	self withUpdateLog: '- Issue 2665:	Fixed broken string in selection evaluation.
- Add System-Installers as package (empty but code is coming)'.
	self loadTogether: self script43 merge: false.
	self addPackage: 'System-Installers'.
self removeAllRepositories.
self addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 18:43'!
update12047
	"self new update12047"
	self withUpdateLog: 'Issue 2664:	Lost some classes only sarInstaller and MczInstaller'.
	self loadTogether: self script44 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 18:54'!
update12048
	"self new update12048"
	self withUpdateLog: '- Issue 2664: empty classes: WebBrowser, SketchMorph, PasteUpMorphTest, NameOfSubclass, MethodTempsNode'.
	self loadTogether: self script45 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 23:10'!
update12049
	"self new update12049"
	self withUpdateLog: '- Issue 2501: Refactored directory scanning
- PackageOrganizer enh
- Issue 2623: Make sure MCWorkingCopy receives system change notifications by reregistering for them on startup.'.
	self loadTogether: self script46 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/17/2010 13:41'!
update12050
	"self new update12050"
	self withUpdateLog: '- Issue 2671:	SelectedObjectThumbnail should be removed
- Issue 2669:	ProgressMorph should be removed
- Issue 2675:	Push everything from PSUIManager to MorphicUIManager'.
	self loadTogether: self script47 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/17/2010 15:29'!
update12051
	"self new update12051"
	self withUpdateLog: 'Issue 2201:	SarInstaller refers to SqueakMap
Issue 2680:	Renaming a key in a dictionary and cancelling renames the key to nil'.
	self loadTogether: self script48 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/17/2010 16:02'!
update12052
	"self new update12052"
	self withUpdateLog: '- Issue 2676: PluggableTextMorphPlusRemoval'.
	self loadTogether: self script49 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 11:08'!
update12053
	"self new update12053"
	self withUpdateLog: 'preparing unload of preferences'.
	self loadTogether: self script50 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 11:14'!
update12054
	"self new update12054"
	self withUpdateLog: 'preparing unload of preferences 2'.
	self loadTogether: self script51 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 11:23'!
update12055
	"self new update12055"
	self withUpdateLog: 'Remove PreferenceBrowser'.
	self loadTogether: self script52 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 12:12'!
update12056
	"self new update12056"
	self withUpdateLog: 'Issue 2676 - Remove PluggableListMorphPlus'.
	self loadTogether: self script53 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 12:56'!
update12057
	"self new update12057"
	self withUpdateLog: 'Issue 2676 - Really removing the classes PluggableListMorphPlus'.
	self loadTogether: self script54 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 13:48'!
update12058
	"self new update12058"
	self withUpdateLog: 'Issue 2676 - remove PluggableButtonMorphPlus'.
	self loadTogether: self script55 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 14:25'!
update12059
	"self new update12059"
	self withUpdateLog: 'Issue 2676 - remove PluggableButtonMorphPlus reference'.
	self loadTogether: self script56 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 15:25'!
update12060
	"self new update12060"
	self withUpdateLog: 'Large cleaning of PasteUpMorph underway'.
	self loadTogether: self script57 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 17:07'!
update12061
	"self new update12061"
	self withUpdateLog: 'removing donor and partBin'.
	self loadTogether: self script58 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/19/2010 22:58'!
update12062
	"self new update12062"
	SystemChangeNotifier uniqueInstance notify: Smalltalk ofAllSystemChangesUsing: #event:.
	self withUpdateLog: '- Issue 2694:	MC screwing up ancestry
- Issue 2684:	Deleting a method is not logged	
		SystemChangeNotifier uniqueInstance notify: Smalltalk ofAllSystemChangesUsing: #event:.
-  Issue 2681:	easily browse the variables defined in a workspace'.
	self loadTogether: self script59 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/21/2010 18:15'!
update12063
	"self new update12063"
	self withUpdateLog: '- Issue 2708:	Cleaning a bit systemnavigation.
- Issue 2701:	fix duplicate entries handling in recentmessageset	. Thanks benjamin
- Issue 2702:	Better duller from Squeak.
- Issue 2689:	random morph unused code cleanups
-  Issue 2699:	Hex for Cog
'.
	self loadTogether: self script60 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/23/2010 12:38'!
update12064
	"self new update12064"
	self withUpdateLog: '- Issue 2711:	SmartRefStream (and hence also ImageSegment) are broken due to missing #convertToCurrentVersion:refStream:'.
	self loadTogether: self script61 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/23/2010 21:24'!
update12065
	"self new update12065"
	self withUpdateLog: '- Issue 2654:	ChangeList ENH from eliot. '.
	self loadTogether: self script62 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/26/2010 12:44'!
update12066
	"self new update12066"
	self withUpdateLog: 'Issue 2712:	Once
Issue 2715:	remove three methods from Object: evaluateUnloggedForSelf, stringRepresentation, stringForReadout
Issue 2529:	FreeTypeFont>>veryDeepCopyWith:
'.
	self loadTogether: self script63 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/27/2010 09:47'!
update12067
	"self new update12067"
	self withUpdateLog: 'Issue 670:	should clean Morph menu
Issue 2716:	New graphics for mouse over on window controls'.
	self loadTogether: self script64 merge: false.
	UITheme current class beCurrent.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/27/2010 15:05'!
update12068
	"self new update12068"
	self withUpdateLog: 'Issue 2719:	CachedBlockClosure >> value should uncache block
Issue 2695:	Tasklist on Mac'.
	self loadTogether: self script65 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/29/2010 20:46'!
update12069
	"self new update12069"
	self withUpdateLog: 'Issue 1699:	A File out of existing code aborts when canceled
Issue 2722:	Fix some Undeclared References in 12068
Issue 2700:	Bug opening TestRunner in 12062 and 12061'.
	self loadTogether: self script66 merge: false.
	Compiler recompileAll.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/29/2010 22:05'!
update12070
	"self new update12070"
	self withUpdateLog: 'Issue 2723:	TestRunner UI does not provide fly by help for buttons
Issue 2724:	Window button fly by help should start with uppercase
Issue 2725:	Debugger context menu items do not start with uppercase letter
Issue 2726:	Fly by help of debugger buttons should start with uppercase'.
	self loadTogether: self script67 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/31/2010 19:58'!
update12071
	"self new update12071"
	self withUpdateLog: '- Issue 2732:	Paste Up Clean up post actions required
- Issue 2731:	SystemNavigation cleaning
- Issue 2730:	Dialog cleaning
- Issue 2728:	MCSubDirectoryRepository should not use / but
- Issue 2709:	printStringHex for Character'.
	self loadTogether: self script68 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/1/2010 13:21'!
update12072
	"self new update12072"
	self withUpdateLog: '- Issue 2727:	Consistency by providing uppercase menu items in Tools menus (Part 2). Thanks Torsten. There are no such little fixes :)'.
	self loadTogether: self script69 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/1/2010 22:07'!
update12073
	"self new update12073"
	self withUpdateLog: '- Issue 1289:	Changing locale raises DNU
- test categories cleaning. Thanks alexandre.
- Issue 2205:	pluggable Tree Morph deselect behavior. Tx Laurent.'.
	self loadTogether: self script70 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/2/2010 23:40'!
update12074
	"self new update12074"
	self withUpdateLog: '- Issue 2169:	FileDirectory>>matchingEntries: criteria is broken. Thanks CarloTeixeira.
	
-  Issue 2738:	Browse instance/?/class button should provide fly by help. Thanks Torsten Bergmann.
	
- Issue 1068:	Mac: Quit from host menu not working anymore. Thanks Mike Roberts.
	
- Issue 2721:	Extending SUnit to emit announcement. Thanks Alexandre Bergel'.
	self loadTogether: self script71 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 14:31'!
update12075
	"self new update12075"
	self withUpdateLog: '- Issue 2296: Point>>closeTo. Thanks Alexandre Bergel and Henrik Johanssen.

- SUnit Announcement post fix.

- Issue 2617:	Fix restart in blocks in debugger. Thanks Henrik Johanssen.
	
-  Issue 2364:	FileList menu more... is bogus. Thanks Carlo Teixeira
	
-  Issue 1767:	Method Finder gives UndefinedObject error on search. Thanks Alexandre Bergel. Thanks Marcus, patchinko and  Gary.'.
	self loadTogether: self script72 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 15:51'!
update12076
	"self new update12076"
	self withUpdateLog: '- Issue 2347:	Migrating some OS queries from SmalltalkImage to OSPlatform. This changes is really nice since it used the existing Platform classes for that they should. 
	Now do you use Smalltalk os, Smalltalk platform but 
	OSPlatform os
	OSPlatform platform
This way OSPlatform is used for what it should. It would be nice if Squeak would follow this change, else we will add a compatibility package. Thanks Simon Denier.'.
	self loadTogether: self script73 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 17:36'!
update12077
	"self new update12077"
	self withUpdateLog: '- Issue 2347:  fixing Problem with previous release vmVersion was missing. 
- Issue 2745: Text>>fromString; , does not add by default a (TextColor color: Color black ) attribute. Thanks Fernando Olivero.

- Issue 2662:	value: primitives. Thanks Eliot Miranda, Henrik Johanssen.

- Issue 2603:	isRunningCog. Thanks Andreas Raab, German Arduino.
	
- Issue 2609:	getSystemAttribute: 2 -> documentPath. Thanks German Arduino.'.
	self loadTogether: self script74 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 18:52'!
update12078
	"self new update12078"
	self withUpdateLog: '- Issue 2661: File name correction for unix to allow. Thanks Eliot Miranda, German Ardino.

- Issue 2122:	superclassOrder: is defined on Changeset. Now defined on Class. Thanks Steven Freeman.
	
- Fixed OSPlatform vmVersion'.
	self loadTogether: self script75 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 19:47'!
update12079
	"self new update12079"
	self withUpdateLog: '- Issue 2655:	Fix the other dependencies of asContextWithSender:'.
	self loadTogether: self script76 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 23:10'!
update12080
	"self new update12080"
	self withUpdateLog: '- Issue 1298:	CrLfFileStream not properly initialized on Mac OS. Thanks Andrew Black and Carlo Teixeira	'.
	self loadTogether: self script77 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/4/2010 11:58'!
update12081
	"self new update12081"
	self withUpdateLog: '- Fixing vmVersion comments and guessDefaultEndline

- Issue 2746: NewTextMorph now uses theme text adornments
Polymorph text addornment and other minor refactorings to NewTextMorph and related classes. Thanks Fernando Olivero

-  Issue 2749:	NewTextMorph does not react to enter and escape keystrokes. Thanks Fernando Olivero'.
	self loadTogether: self script78 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/4/2010 13:07'!
update12082
	"self new update12082"
	self withUpdateLog: '- Issue 2751:	Recover last changes broken'.
	self loadTogether: self script79 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/5/2010 15:29'!
update12083
	"self new update12083"
	self withUpdateLog: 'Issue 2749:	NewTextMorph does not react to enter and escape keystrokes (part 2)
Issue 2750:	Loading an image segment can introduce a class named AnObsoleteFake37SomeName'.
	self loadTogether: self script80 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/8/2010 18:54'!
update12084
	"self new update12084"
	self withUpdateLog: '-  Issue 2760:	More robust handling of HTTP upload responses. Thanks Andreas Raab.
	
-  Issue 2753:	introduce Smalltalk  platform to forward to OSPlatform.
	
- Issue 2761:	Some Cog-specific VM attribute accessors
	
- Issue 2763:	SocketStream destroy. Thanks Andreas Raab.
	
- Better xIllegal message. Thanks Nicolas Cellier

- Better Rectangle class comment. Thanks Nicolas Cellier
'.
	self loadTogether: self script81 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/9/2010 17:09'!
update12085
	"self new update12085"
	self withUpdateLog: 'Issue 2774:	UTF16TextConverter incorrectly writes/does not write BOMs in different circumstances
Issue 2765:	SocketStreamTest are green in Squeak and hang on Pharo (add test)'.
	self loadTogether: self script82 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/10/2010 21:42'!
update12086
	"self new update12086"
	self withUpdateLog: '- Issue 2752: Metacello configuration browser. Thanks Torsten Bergmann.
- Issue 2776: UTF16TextConverter write speedup. Thanks Henrik Johanssen.
- Issue 2777:	Polymorph enhancements. Thanks Gary Chambers.'.
	self loadTogether: self script83 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/10/2010 22:34'!
update12087
	"self new update12087"
	self withUpdateLog: '- Issue 2573:	Make it possible to run cleanup non-interactively. Thanks Andreas Raab and German Arduino.
	
- Issue 2756:	Morphic Cleansing - Remove use of findA:. Thanks Guillermo Polito.

- Package name test. Thanks Luc Fabresse.'.
	self loadTogether: self script84 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/11/2010 12:50'!
update12088
	"self new update12088"
	self withUpdateLog: '- Issue 2683:	new slice package should get inbox by default as repository. Thanks Carlo Teixeira
	
- Issue 2754:	DateAndTime instance creation from a string or stream sets offset to 0. Thanks Sean De Nigris.
- DateAndTime instance creation from strings and streams default to local offset if none is specified (e.g. via class >>readFrom: and class>>fromString:). 

- DateAndTime tests updated
	- testReadFromSecond renamed to testPrintStringSecond
	- added tests for the default offset condition described above
	- added test of class>>fromString:
	
- Issue 2782:	Monticello UI does not make newly added slice or package the selected package. Thanks Carlo Teixeira
	
- Issue 2783:	Bitmap>>compressGZip unused.
	
-  Issue 2784:	More uppercase menues for file service menues.  Grogeous and dead simple but needed. Thanks Torsten Bergmann. '.
	self loadTogether: self script85 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/14/2010 23:12'!
update12089
	"self new update12089"
	self withUpdateLog: 'Issue 2798:	Replace Set class>>rehashAllSets with HashedCollection class>>rehashAllSubInstances	
Issue 2796:	Preference cleanup 1: remove 50 unsent methods
Issue 2795:	Remove some unused variables
Issue 2789:	Nuke TestRunner>>hasHistory
Issue 2800:	remove MethodContext>>#freeNames
Issue 2785:	File list menu should have grouped items	'.
	self loadTogether: self script86 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 11:10'!
update12090
	"self new update12090"
	self withUpdateLog: 'Issue 2656:	Fix MessageNames for references to non-selectors.
Issue 2674:	Slider should be moved to Morphic-Widgets
Issue 2801:	Add standard deviation to Collections math methods
Issue 2572:	asCamelCase

'.
	self loadTogether: self script87 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 13:16'!
update12091
	"self new update12091"
	self withUpdateLog: 'Issue 2791:	Diff browser lost menu item "Install incoming version"
Issue 2802:	Preferences Clean 2'.
	self loadTogether: self script88 merge: false.
	"Preferences removeObsolete."
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 13:42'!
update12092
	"self new update12092"
	self withUpdateLog: 'Issue 2803:	Final Preference Clean
'.
	self loadTogether: self script89 merge: false.
	ScriptLoader new cleanUpForRelease.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 19:18'!
update12093
	"self new update12093"
	self withUpdateLog: 'Issue 2807:	Small cleanup for Inspector
Issue 2806:	small code-critique cleanup of FileList
Issue 2799:	Class binding'.
	self loadTogether: self script90 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/16/2010 09:12'!
update12094
	"self new update12094"
	self withUpdateLog: 'Issue 2809:	Some trivial cleanup for Browser and related classes
Issue 2808:	improved isAbstractClass
Issue 1619:	Error when using decompress in the file list on a mac zip file
Issue 2797:	MIMEDocument class >> #guessTypeFromName: results in MNU (added the test)'.
	self loadTogether: self script91 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/16/2010 15:32'!
update12095
	"self new update12095"
	self withUpdateLog: 'Issue 2526:	Add Save Button to Monticello Repository View
Issue 2618:	a bit faster DependentsArray >> #select:
Issue 2513:	NewTextMorph does not accept on cmd-s.
Issue 2811:	Environment in Trait>>copy
'.
	self loadTogether: self script92 merge: false.
	TextEditor initialize.
SmalltalkEditor initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'stephaneducasse 8/16/2010 23:24'!
update12096
	"self new update12096"
	self withUpdateLog: '- Add Preferences empty class else I have to manually create before merging. This way we can merge and worked to turn the preference in setting. 

- Issue 1921:	Class>>Binding Fix. Thanks Andreas Raab. Guillermo Polito. I integrated it with the previous change I did.
	'.
	self loadTogether: self script93 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/17/2010 20:12'!
update12097
	"self new update12097"
	self withUpdateLog: '- Issue 2814:	Mods for Sugar theme support and (pluggable) label getter. Thanks Gary Chambers and Hilaire Fernandes
	
- Issue 2821:	Fixes for DropListMorph/EditableDropListMorph. Thanks Gary Chambers.'.
	self loadTogether: self script94 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/18/2010 11:42'!
update12098
	"self new update12098"
	self withUpdateLog: 'Issue 2826:	add empty PluggableButtonMorphPlus
Issue 2824:	PluggableTextMorphWithModel is not used
Issue 2333:	MCSnapshotBrowser>>allClassNames would incorrectly list the classe'.
	self loadTogether: self script95 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/19/2010 11:24'!
update12099
	"self new update12099"
	self withUpdateLog: '- Removed possiblyChanged sent but not implemented methods in NewEditor. Issue 2827:	remove all the senders of possiblyChanged

- Issue 2829:	Improve Watery2 theme drop list appearance. Thanks Gary Chambers.'.
	self loadTogether: self script96 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/19/2010 22:42'!
update12100
	"self new update12100"
	self withUpdateLog: '- Enter back to accept TextEntryDialogWindow. Thanks Gary Chambers.

- Issue 2833:	Pharo 1.1 final has two senders of #haltOnce
	
- fixes some Smalltalk -> Smalltalk globals'.
	self loadTogether: self script97 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/20/2010 11:55'!
update12101
	"self new update12101"
	self withUpdateLog: 'Issue 2835:	remove dead code from MorphicModel
Issue 2837:	Trivial code-critique cleanup of CodeLoader and related
Issue 2836:	remove ColorPatchCanvas and some other etoy related code'.
	self loadTogether: self script98 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/20/2010 22:32'!
update12102
	"self new update12102"
	self withUpdateLog: '- Issue 2810:	Missing "Software update" menu in releases confusing new users
	
- Issue 2812:	Add ISO-8859-15 and CP-1252 encodings support. Thanks Philipp Marshall.'.
	self loadTogether: self script99 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/21/2010 22:11'!
update12103
	"self new update12103"
	self withUpdateLog: '- Issue 2839:	ContextInspector. Thanks Andreas Raab
- Issue 2840:	UUID class>>fromString36:. Thanks Nicolas Cellier.
	http://bugs.squeak.org/view.php?id=7262'.
	self loadTogether: self script100 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:09'!
updateUpdatesList: aString
	"ScriptLoader new updateUpdatesList: 'cleanUpMethods'"
	
	| str |
	str := FileDirectory default oldFileNamed: 'updates.list'.
	[	str
			setToEnd;
			cr;
			nextPutAll: self currentUpdateVersionNumber asString;
			nextPutAll: '-Pha-', aString, '.cs' ]
		ensure: [ str close ]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'lr 3/14/2010 21:13'!
verifyNewUpdate
	self repository: self class defaultMCWaitingFolder.
	self class loadLatestPackage: 'ScriptLoader' fromRepository: self repository.
	self perform: ('update' , self getLatestUpdateNumber asString) asSymbol.
	(self confirm: 'Completed loading the new update. Run all test now?')
		ifTrue: [ 
			Author fullName: 'tester'.
			Smalltalk globals at: #TestRunner ifPresent: [ :class | class open model runAll ] ]! !

!ScriptLoader methodsFor: 'private' stamp: 'al 11/1/2008 18:19'!
waitingFolderMCZFiles
	^ self class defaultMCWaitingFolder allFileNames
		reject: [:each | each =  '.DS_Store']! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/24/2008 16:45'!
withUpdateLog: aString

	self logStream nextPutAll: ' ------------------------------------------------------' ; cr.
	self logStream nextPutAll: thisContext sender selector asString. 
	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'sd 3/24/2008 17:31'!
workingCopyFromPackageName: aString
	"self new workingCopyFromPackageName: '39Deprecated' "
	
	|pa|
	pa := MCPackage named: aString.
	^ pa workingCopy 
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 7/8/2006 18:20'!
writeCS: extensionAndNumber forUpdate: updateNumber
	"ScriptLoader new writeCS: '-sd.210' forUpdate: 7037"
	
	self writeCS: extensionAndNumber forUpdate: updateNumber withName: 'changeMe'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 2/25/2010 18:09'!
writeCS: extensionAndNumber forUpdate: updateNumber withName: aSt
	"ScriptLoader new writeCS: '-md.2929' forUpdate: 7049 withName: 'cleanUpMethods'"
	

	FileDirectory default 
		forceNewFileNamed:  updateNumber asString, 'update', aSt, '.cs'
		do: [ :stream | self generateCS: extensionAndNumber fromUpdate: updateNumber on: stream].
! !
ScriptLoader initialize!
